from setuptools import find_packages, setup

setup(
    name="noisereduce",
    packages=find_packages(),
    version="0.1.0",
    description="Noise reduction using Spectral Gating in python",
    author="Tim Sainburg",
    license="MIT",
)
